@@ -110,12 +110,13 @@ class XmlConfiguration:
 
 
 class ComplexArguments:
-    def __init__(self, sub_arg_objs: dict, with_group_prefix=False):
+    def __init__(self, sub_arg_objs: dict, with_group_prefix=False, conflict_warning=True):
         self._parser = argparse.ArgumentParser()
         self._subparsers = self._parser.add_subparsers(help='sub-command help', dest='cmd')
         self._subparsers.required = True
         self._sub_arg_objs = sub_arg_objs
         self._with_group_prefix = with_group_prefix
+        self._conflict_warning = conflict_warning
         self._arg_objs = {}
         self.__create_args()
 
@@ -123,7 +124,7 @@ class ComplexArguments:
         for sub, arg_obj in self._sub_arg_objs.items():
             if arg_obj is None: continue
             parser = self._subparsers.add_parser(sub, help='{} help'.format(sub))
-            self._arg_objs[sub] = Arguments(arg_obj, parser, self._with_group_prefix)
+            self._arg_objs[sub] = Arguments(arg_obj, parser, self._with_group_prefix, self._conflict_warning)
 
     def _get_arg_obj(self, sub, args):
         argument: Arguments = self._arg_objs[sub]
@@ -140,10 +141,11 @@ class ComplexArguments:
 
 
 class Arguments:
-    def __init__(self, configObj, parser=None, with_group_prefix=False):
+    def __init__(self, configObj, parser=None, with_group_prefix=False, conflict_warning=True):
         self.parser = argparse.ArgumentParser() if parser is None else parser
         self.destObj = configObj
         self.with_group_prefix = with_group_prefix
+        self.conflict_warning = conflict_warning
         self.groups = dict()
         self.configInspector = ConfigInspector(self.destObj)
         self._arg_obj(self.configInspector, self.parser)
@@ -151,8 +153,10 @@ class Arguments:
     def __get_type_action(self, field):
         action = 'store'
         if field.type == bool:
-            if field.default: return 'store_false'
-            else: return 'store_true'
+            if field.default:
+                return 'store_false'
+            else:
+                return 'store_true'
         return action
 
     def __get_group(self, groupName, help=''):
@@ -170,6 +174,11 @@ class Arguments:
         required = True
         if v is None: required = False
         name = name.replace('_', '-')
+
+        if parser.get_default(name) and self.conflict_warning:
+            print('WARNING: duplicated argument defined on: ' + name)
+            return self
+
         parser.add_argument('--' + name,
                             default=v,
                             required=required,
